Simple bots or Simbots is a library designed to create simple bots using the power of python. This library utilises Intent, Entity, Relation and Context
model to create bots . It uses a multinomial NB classifier to create intent classifiers.

To install simply use 

    pip install simbots

Links
 
 1) [Documentation](https://vaibhavrr1.github.io/simbots/index.html) 
 2) [pypi](https://pypi.org/project/simbots/)
 3) [github](https://github.com/vaibhavrr1/simbots)
 
 
 